==> duiba-service-api-1.7.0-20160929.154812-1-sources.jar: cn/com/duiba/service/domain/dataobject/EmbedDO.java <==
package cn.com.duiba.service.domain.dataobject;

import java.io.Serializable;

public class EmbedDO implements Serializable {

	private static final long serialVersionUID = 8562509993801982826L;
	public static final String SourceTypeNormal = "normal"; // 普通兑换
	public static final String SourceTypeDuibaActivity = "activity"; //兑吧专题活动
	public static final String SourceTypeSingleLottery = "singlelottery";//单品抽奖活动
	public static final String SourceTypeHdtool = "hdtool";//活动工具（摇一摇抽奖,老虎机,刮刮卡抽奖，幸运转盘）
	public static final String SourceTypeHdtoolTurntable = "turntable";//活动工具大转盘
	public static final String SourceTypeSecondsKill = "secondkill";//秒杀专题
	public static final String SourceTypeGame = "game";//游戏
	public static final String SourceTypeDuibaQuestionAnswer = "question";//兑吧答题活动
	public static final String SourceTypeNgame = "ngame";//游戏
	public static final String SourceTypeLittleGame = "littleGame";//小游戏
	public static final String SourceTypeGuess = "guess";//
	//Start guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
	public static final String SourceTypeDuibaQuizz = "duibaQuizz";//兑吧测试题活动
	public static final String SourceTypeDuibaSeckill = "duibaSeckill";//秒杀活动
	//End guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
	
	//按钮埋点号码
	public static final String ButtonType_SingleLottery = "30001";//单品抽奖活动
	public static final String ButtonType_Turntable = "30002";//兑换记录详情页
	public static final String ButtonType_Hdtool = "40003";//活动工具
	public static final String ButtonType_Guess = "40004";//竞猜
	public static final String ButtonType_QuestionAnswer = "40005";//答题
	public static final String ButtonType_Quizz = "40006";//测试题
	public static final String ButtonType_SingleLottery_Duiba = "40007";//单品抽奖活动
	public static final String ButtonType_RecordDetailNew = "40001";//兑换成功通知页
	public static final String ButtonType_RecordDetail = "40002";//兑换记录详情页
	public static final String ButtonType_Record = "50003";//兑换详情页
	public static final String ButtonType_Mobil_RecordDetailNew = "50001";//兑换成功通知页
	public static final String ButtonType_Mobil_RecordDetail = "50002";//兑换记录详情页
	
	public static final String ButtonType_RrecordList = "20001";//列表
	public static final String ButtonType_Lottery = "20002";//抽奖活动
	public static final String ButtonType_All = "20003";//所有兑换项
	public static final String ButtonType_Coupon = "20004";//优惠券
	public static final String ButtonType_Object = "20005";//实物兑换
	public static final String ButtonType_Classify = "20006";//自定义
	
	public static final String ButtonType_Rob_List_Qiang = "40008";//今日必抢列表：抢
	public static final String ButtonType_Rob_Detail_qiang = "40009";//今日必抢详情-现在去抢
	public static final String ButtonType_Rob_Detail = "20011";//今日必抢：活动详情
	public static final String ButtonType_Rob_Ling = "20013";//今日必抢：领
	public static final String ButtonType_Rob_Kan= "30009";//砍一下
	public static final String ButtonType_RobLing = "30010";//立即领取

	public static final String ButtonType_Banner = "10001";//banner
	public static final String ButtonType_Icon = "10002";//图标区
	public static final String ButtonType_Image = "10004";//图标区

	public static final String ButtonType_Plant = "20007";//平台券
	public static final String ButtonType_ShowCase = "10003";//橱窗
	public static final String ButtonType_Main = "10007";//浮标
	public static final String ButtonType_Rrecord = "10005";//浮标
	public static final String ButtonType_ItemDetail_User = "80001";//兑换详情页马上兑换
	public static final String ButtonType_ItemSuccess_Return = "80002";//兑换回到首页
	
	//小游戏 ButtonType  ===== start  =======cdm   2016-9-26
    public static final String ButtonType_LittleGame_BuyOrStart = "120001";//购买/开始游戏
    public static final String ButtonType_LittleGame_HtmlPv = "120002";//页面曝光
    public static final String ButtonType_LittleGame_EndGame = "130001";//结束弹层-曝光
    public static final String ButtonType_LittleGame_ReceiveFree = "130002";//免费领取
    public static final String ButtonType_LittleGame_PlayAgain = "130003";//再玩儿一次
    public static final String ButtonType_LittleGame_MoreGame = "130004";//更多游戏
    //小游戏 ButtonType  ===== end  =======cdm   2016-9-26
    
	//细节类型
	public static final String InfoType_Items = "1";//兑换页
	public static final String InfoType_Ad = "2";//广告
	public static final String InfoType_AppManualLottery  = "3";//自有活动
	public static final String InfoType_Duiba_Activity = "4";//专题活动
	public static final String InfoType_SingleLottery = "5";//单品抽奖
	public static final String InfoType_Turntable = "6";//幸运转盘
	public static final String InfoType_Hdtool = "7";//活动工具
	public static final String InfoType_Game = "8";//游戏
	public static final String InfoType_NGame = "9";//新游戏
	public static final String InfoType_SecondsKill = "10";//秒杀专题
	public static final String InfoType_Seckill = "11";//秒杀活动
	public static final String InfoType_Question = "12";//答题
	public static final String InfoType_Quizz = "13";//测试题
	public static final String InfoType_Guess = "14";//竞猜
	public static final String InfoType_Link = "15";//自定义链接
	
	public static final String InfoType_Icon = "17";//图标区-指向列表
	public static final String InfoType_AppItem = "18";//自有兑换项
	public static final String InfoType_Plant = "19";//平台券
	public static final String InfoType_Brick = "20";//皮肤
	public static final String InfoType_Rob = "21";//今日必抢
	public static final String InfoType_Banner = "22";//banner区 
    public static final String InfoType_ShowCase = "23";//橱窗区
    public static final String InfoType_MainMeet = "24";//主会场
    public static final String InfoType_LittleGame = "25";//小游戏
    
	
	public static final String LoginType = "1";//登录
	public static final String LoginTypeNo = "0";//未登录
	
	public static final String OS_ANDROID = "0";//android
	public static final String OS_IPHONE = "1";//iphone
	public static final String OS_WINDOWS = "2";//windows
	public static final String OS_MACINTOSH = "3";//macintosh
	public static final String OS_IPAD = "4";//IPAD
	public static final String OS_LINUX = "5";//linux
	public static final String OS_UNKNOWN = "6";//Unknown
	//End guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
}

==> duiba-service-api-1.7.7.4-sources.jar: cn/com/duiba/service/domain/dataobject/EmbedDO.java <==
package cn.com.duiba.service.domain.dataobject;

import java.io.Serializable;

public class EmbedDO implements Serializable {

	private static final long serialVersionUID = 8562509993801982826L;
	public static final String SourceTypeNormal = "normal"; // 普通兑换
	public static final String SourceTypeDuibaActivity = "activity"; //兑吧专题活动
	public static final String SourceTypeSingleLottery = "singlelottery";//单品抽奖活动
	public static final String SourceTypeHdtool = "hdtool";//活动工具（摇一摇抽奖,老虎机,刮刮卡抽奖，幸运转盘）
	public static final String SourceTypeHdtoolTurntable = "turntable";//活动工具大转盘
	public static final String SourceTypeSecondsKill = "secondkill";//秒杀专题
	public static final String SourceTypeGame = "game";//游戏
	public static final String SourceTypeDuibaQuestionAnswer = "question";//兑吧答题活动
	public static final String SourceTypeNgame = "ngame";//游戏
	public static final String SourceTypeLittleGame = "littleGame";//小游戏
	public static final String SourceTypeGuess = "guess";//
	//Start guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
	public static final String SourceTypeDuibaQuizz = "duibaQuizz";//兑吧测试题活动
	public static final String SourceTypeDuibaSeckill = "duibaSeckill";//秒杀活动
	//End guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
	
	//按钮埋点号码
	public static final String ButtonType_SingleLottery = "30001";//单品抽奖活动
	public static final String ButtonType_Turntable = "30002";//兑换记录详情页
	public static final String ButtonType_Hdtool = "40003";//活动工具
	public static final String ButtonType_Guess = "40004";//竞猜
	public static final String ButtonType_QuestionAnswer = "40005";//答题
	public static final String ButtonType_Quizz = "40006";//测试题
	public static final String ButtonType_SingleLottery_Duiba = "40007";//单品抽奖活动
	public static final String ButtonType_RecordDetailNew = "40001";//兑换成功通知页
	public static final String ButtonType_RecordDetail = "40002";//兑换记录详情页
	public static final String ButtonType_Record = "50003";//兑换详情页
	public static final String ButtonType_Mobil_RecordDetailNew = "50001";//兑换成功通知页
	public static final String ButtonType_Mobil_RecordDetail = "50002";//兑换记录详情页
	
	public static final String ButtonType_RrecordList = "20001";//列表
	public static final String ButtonType_Lottery = "20002";//抽奖活动
	public static final String ButtonType_All = "20003";//所有兑换项
	public static final String ButtonType_Coupon = "20004";//优惠券
	public static final String ButtonType_Object = "20005";//实物兑换
	public static final String ButtonType_Classify = "20006";//自定义
	
	public static final String ButtonType_Rob_List_Qiang = "40008";//今日必抢列表：抢
	public static final String ButtonType_Rob_Detail_qiang = "40009";//今日必抢详情-现在去抢
	public static final String ButtonType_Rob_Detail = "20011";//今日必抢：活动详情
	public static final String ButtonType_Rob_Ling = "20013";//今日必抢：领
	public static final String ButtonType_Rob_Kan= "30009";//砍一下
	public static final String ButtonType_RobLing = "30010";//立即领取

	public static final String ButtonType_Banner = "10001";//banner
	public static final String ButtonType_Icon = "10002";//图标区
	public static final String ButtonType_Image = "10004";//图标区

	public static final String ButtonType_Plant = "20007";//平台券
	public static final String ButtonType_ShowCase = "10003";//橱窗
	public static final String ButtonType_Main = "10007";//浮标
	public static final String ButtonType_Rrecord = "10005";//浮标
	public static final String ButtonType_ItemDetail_User = "80001";//兑换详情页马上兑换
	public static final String ButtonType_ItemSuccess_Return = "80002";//兑换回到首页
	
	
	//积分游戏埋点
	public static final String ButtonType_CreditGame_GameStart = "110001";//开始游戏
	public static final String ButtonType_CreditGame_GameAgain = "110002";//再玩一次
	public static final String ButtonType_CreditGame_ImmediateAward = "110003";//立即领奖
	public static final String ButtonType_CreditGame_Elastic_Img = "110004";//弹层-图片
	public static final String ButtonType_CreditGame_Elastic_Close = "110005";//弹层-X关闭
	public static final String ButtonType_CreditGame_Elastic_UseMethod ="110006";//弹层-查看使用方法
	public static final String ButtonType_CreditGame_Elastic_Exposure = "110007";//弹层-曝光弹层
	public static final String ButtonType_CreditGame_Elastic_UseDetail = "110008";//弹层-点击查看使用详情
	public static final String ButtonType_CreditGame_Elastic_UseImmediate = "110009";//弹层-马上使用
	public static final String ButtonType_CreditGame_MyAward = "110010";//我的奖品
	//积分游戏埋点
	
	//小游戏 ButtonType  ===== start  =======cdm   2016-9-26
    public static final String ButtonType_LittleGame_BuyOrStart = "120001";//购买/开始游戏
    public static final String ButtonType_LittleGame_HtmlPv = "120002";//页面曝光
    public static final String ButtonType_LittleGame_EndGame = "130001";//结束弹层-曝光
    public static final String ButtonType_LittleGame_ReceiveFree = "130002";//免费领取
    public static final String ButtonType_LittleGame_PlayAgain = "130003";//再玩儿一次
    public static final String ButtonType_LittleGame_MoreGame = "130004";//更多游戏
    //小游戏 ButtonType  ===== end  =======cdm   2016-9-26
    
    //小游戏 ButtonType 详情页 ===== start  =======cdm   2016-10-09
    public static final String ButtonType_LittleGameDetail_UseNow = "130005";//马上使用
    public static final String ButtonType_LittleGameDetail_PrizePv = "130006";//卷弹出曝光
    public static final String ButtonType_LittleGameDetail_UseDetail = "130007";//查看使用详情
    public static final String ButtonType_LittleGameDetail_Image = "130008";//图片
    public static final String ButtonType_LittleGameDetail_CloseButton = "130009";//关闭
    public static final String ButtonType_LittleGameDetail_UseButton = "130010";//使用按钮
    //小游戏 ButtonType 详情页 ===== end  =======cdm   2016-10-09
    
	//细节类型
	public static final String InfoType_Items = "1";//兑换页
	public static final String InfoType_Ad = "2";//广告
	public static final String InfoType_AppManualLottery  = "3";//自有活动
	public static final String InfoType_Duiba_Activity = "4";//专题活动
	public static final String InfoType_SingleLottery = "5";//单品抽奖
	public static final String InfoType_Turntable = "6";//幸运转盘
	public static final String InfoType_Hdtool = "7";//活动工具
	public static final String InfoType_Game = "8";//游戏
	public static final String InfoType_NGame = "9";//新游戏
	public static final String InfoType_SecondsKill = "10";//秒杀专题
	public static final String InfoType_Seckill = "11";//秒杀活动
	public static final String InfoType_Question = "12";//答题
	public static final String InfoType_Quizz = "13";//测试题
	public static final String InfoType_Guess = "14";//竞猜
	public static final String InfoType_Link = "15";//自定义链接
	
	public static final String InfoType_Icon = "17";//图标区-指向列表
	public static final String InfoType_AppItem = "18";//自有兑换项
	public static final String InfoType_Plant = "19";//平台券
	public static final String InfoType_Brick = "20";//皮肤
	public static final String InfoType_Rob = "21";//今日必抢
	public static final String InfoType_Banner = "22";//banner区 
    public static final String InfoType_ShowCase = "23";//橱窗区
    public static final String InfoType_MainMeet = "24";//主会场
    public static final String InfoType_LittleGame = "25";//小游戏
    public static final String InfoType_CreditGame = "26";//积分游戏
	
	public static final String LoginType = "1";//登录
	public static final String LoginTypeNo = "0";//未登录
	
	public static final String OS_ANDROID = "0";//android
	public static final String OS_IPHONE = "1";//iphone
	public static final String OS_WINDOWS = "2";//windows
	public static final String OS_MACINTOSH = "3";//macintosh
	public static final String OS_IPAD = "4";//IPAD
	public static final String OS_LINUX = "5";//linux
	public static final String OS_UNKNOWN = "6";//Unknown
	//End guoeryang,测试题、秒杀活动类型活动的数据埋点需求支持 ,2016/05/16
}
